==> blueprint-component-mapper-3.8.4.tgz: package/esm/field-array/field-array.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { memo, useContext } from 'react';
import PropTypes from 'prop-types';
import isEqual from 'lodash/isEqual';
import clsx from 'clsx';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
import FieldArrayFF from "@data-driven-forms/react-form-renderer/field-array";
import createUseStyles from "react-jss/dist/react-jss.esm.js";
import { Button } from "@blueprintjs/core/lib/esm/components/button/buttons.js";
import { Intent } from "@blueprintjs/core/lib/esm/common/intent.js";
import { FormGroup } from "@blueprintjs/core/lib/esm/components/forms/formGroup.js";
import BlueprintContext from '../blueprint-context/blueprint-context';
var useStyles = createUseStyles({
  addContainer: {
    display: 'flex',
    flexFlow: 'row-reverse',
    marginBottom: 15
  },
  remove: {
    marginBottom: 15
  }
});
var ArrayItem = memo(function (_ref) {
  var remove = _ref.remove,
      fields = _ref.fields,
      name = _ref.name,
      removeLabel = _ref.removeLabel,
      ArrayItemProps = _ref.ArrayItemProps,
      RemoveButtonProps = _ref.RemoveButtonProps,
      disabledRemove = _ref.disabledRemove;
  var formOptions = useFormApi();

  var _useStyles = useStyles(),
      removeCss = _useStyles.remove;

  var editedFields = fields.map(function (field) {
    return _objectSpread(_objectSpread({}, field), field.name ? {
      name: "".concat(name, ".").concat(field.name)
    } : {
      name: name
    });
  });
  return /*#__PURE__*/React.createElement("div", ArrayItemProps, formOptions.renderForm(editedFields, formOptions), /*#__PURE__*/React.createElement(Button, _extends({
    onClick: remove,
    intent: Intent.DANGER,
    disabled: disabledRemove
  }, RemoveButtonProps, {
    className: clsx(removeCss, RemoveButtonProps && RemoveButtonProps.className)
  }), removeLabel));
}, function (_ref2, _ref3) {
  var _prevRemove = _ref2.remove,
      prev = _objectWithoutProperties(_ref2, ["remove"]);

  var _nextRemove = _ref3.remove,
      next = _objectWithoutProperties(_ref3, ["remove"]);

  return isEqual(prev, next);
});
ArrayItem.propTypes = {
  remove: PropTypes.func,
  fields: PropTypes.array,
  name: PropTypes.string,
  removeLabel: PropTypes.node,
  ArrayItemProps: PropTypes.object,
  RemoveButtonProps: PropTypes.object,
  disabledRemove: PropTypes.bool
};

var FieldArray = function FieldArray(props) {
  var _useFieldApi = useFieldApi(props),
      defaultItem = _useFieldApi.defaultItem,
      fields = _useFieldApi.fields,
      arrayValidator = _useFieldApi.arrayValidator,
      label = _useFieldApi.label,
      description = _useFieldApi.description,
      buttonLabels = _useFieldApi.buttonLabels,
      AddContainerProps = _useFieldApi.AddContainerProps,
      AddButtonProps = _useFieldApi.AddButtonProps,
      RemoveButtonProps = _useFieldApi.RemoveButtonProps,
      ArrayItemProps = _useFieldApi.ArrayItemProps,
      FieldArrayProps = _useFieldApi.FieldArrayProps,
      noItemsMessage = _useFieldApi.noItemsMessage,
      validateOnMount = _useFieldApi.validateOnMount,
      meta = _useFieldApi.meta,
      helperText = _useFieldApi.helperText,
      isRequired = _useFieldApi.isRequired,
      FormGroupProps = _useFieldApi.FormGroupProps,
      maxItems = _useFieldApi.maxItems,
      minItems = _useFieldApi.minItems;

  var _useContext = useContext(BlueprintContext),
      required = _useContext.required;

  var _useStyles2 = useStyles(),
      addContainer = _useStyles2.addContainer;

  var error = meta.error,
      touched = meta.touched,
      submitError = meta.submitError;
  var showError = (validateOnMount || touched) && (error || submitError);
  var text = showError ? error : helperText || description;
  var intent = showError && error && {
    intent: Intent.DANGER
  };
  var labelInfo = isRequired && {
    labelInfo: required
  };

  var combinedLabels = _objectSpread({
    add: 'Add',
    remove: 'Remove'
  }, buttonLabels);

  return /*#__PURE__*/React.createElement(FormGroup, _extends({
    helperText: text,
    label: label
  }, labelInfo, FormGroupProps, intent), /*#__PURE__*/React.createElement(FieldArrayFF, {
    name: props.name,
    validate: arrayValidator
  }, function (fieldArrayProps) {
    return /*#__PURE__*/React.createElement("div", FieldArrayProps, fieldArrayProps.fields.length === 0 && noItemsMessage, fieldArrayProps.fields.map(function (name, index) {
      return /*#__PURE__*/React.createElement(ArrayItem, {
        key: index,
        remove: function remove() {
          return fieldArrayProps.fields.remove(index);
        },
        name: name,
        fields: fields,
        removeLabel: combinedLabels.remove,
        ArrayItemProps: ArrayItemProps,
        RemoveButtonProps: RemoveButtonProps,
        disabledRemove: fieldArrayProps.fields.length <= minItems
      });
    }), /*#__PURE__*/React.createElement("div", _extends({}, AddContainerProps, {
      className: clsx(addContainer, AddContainerProps && AddContainerProps.className)
    }), /*#__PURE__*/React.createElement(Button, _extends({
      onClick: function onClick() {
        return fieldArrayProps.fields.push(defaultItem);
      },
      intent: Intent.SUCCESS,
      disabled: fieldArrayProps.fields.length >= maxItems
    }, AddButtonProps), combinedLabels.add)));
  }));
};

FieldArray.propTypes = {
  name: PropTypes.string,
  defaultItem: PropTypes.any,
  fields: PropTypes.array,
  label: PropTypes.node,
  description: PropTypes.node,
  buttonLabels: PropTypes.object,
  AddContainerProps: PropTypes.object,
  AddButtonProps: PropTypes.object,
  RemoveButtonProps: PropTypes.object,
  ArrayItemProps: PropTypes.object,
  FormGroupProps: PropTypes.object,
  FieldArrayProps: PropTypes.object,
  noItemsMessage: PropTypes.node,
  validateOnMount: PropTypes.bool,
  helperText: PropTypes.node,
  isRequired: PropTypes.bool,
  maxItems: PropTypes.number,
  minItems: PropTypes.number
};
FieldArray.defaultProps = {
  noItemsMessage: 'No items'
};
export default FieldArray;

==> blueprint-component-mapper-3.12.1.tgz: package/esm/field-array/field-array.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { memo, useContext } from 'react';
import PropTypes from 'prop-types';
import isEqual from 'lodash/isEqual';
import clsx from 'clsx';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
import FieldArrayFF from "@data-driven-forms/react-form-renderer/field-array";
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import { Button } from "@blueprintjs/core/lib/esm/components/button/buttons.js";
import { Intent } from "@blueprintjs/core/lib/esm/common/intent.js";
import { FormGroup } from "@blueprintjs/core/lib/esm/components/forms/formGroup.js";
import BlueprintContext from '../blueprint-context/blueprint-context';
var useStyles = createUseStyles({
  addContainer: {
    display: 'flex',
    flexFlow: 'row-reverse',
    marginBottom: 15
  },
  remove: {
    marginBottom: 15
  }
});
var ArrayItem = memo(function (_ref) {
  var remove = _ref.remove,
      fields = _ref.fields,
      name = _ref.name,
      removeLabel = _ref.removeLabel,
      ArrayItemProps = _ref.ArrayItemProps,
      RemoveButtonProps = _ref.RemoveButtonProps,
      disabledRemove = _ref.disabledRemove;
  var formOptions = useFormApi();

  var _useStyles = useStyles(),
      removeCss = _useStyles.remove;

  var editedFields = fields.map(function (field) {
    return _objectSpread(_objectSpread({}, field), field.name ? {
      name: "".concat(name, ".").concat(field.name)
    } : {
      name: name
    });
  });
  return /*#__PURE__*/React.createElement("div", ArrayItemProps, formOptions.renderForm(editedFields, formOptions), /*#__PURE__*/React.createElement(Button, _extends({
    onClick: remove,
    intent: Intent.DANGER,
    disabled: disabledRemove
  }, RemoveButtonProps, {
    className: clsx(removeCss, RemoveButtonProps && RemoveButtonProps.className)
  }), removeLabel));
}, function (_ref2, _ref3) {
  var _prevRemove = _ref2.remove,
      prev = _objectWithoutProperties(_ref2, ["remove"]);

  var _nextRemove = _ref3.remove,
      next = _objectWithoutProperties(_ref3, ["remove"]);

  return isEqual(prev, next);
});
ArrayItem.propTypes = {
  remove: PropTypes.func,
  fields: PropTypes.array,
  name: PropTypes.string,
  removeLabel: PropTypes.node,
  ArrayItemProps: PropTypes.object,
  RemoveButtonProps: PropTypes.object,
  disabledRemove: PropTypes.bool
};

var FieldArray = function FieldArray(props) {
  var _useFieldApi = useFieldApi(props),
      defaultItem = _useFieldApi.defaultItem,
      fields = _useFieldApi.fields,
      arrayValidator = _useFieldApi.arrayValidator,
      label = _useFieldApi.label,
      description = _useFieldApi.description,
      buttonLabels = _useFieldApi.buttonLabels,
      AddContainerProps = _useFieldApi.AddContainerProps,
      AddButtonProps = _useFieldApi.AddButtonProps,
      RemoveButtonProps = _useFieldApi.RemoveButtonProps,
      ArrayItemProps = _useFieldApi.ArrayItemProps,
      FieldArrayProps = _useFieldApi.FieldArrayProps,
      noItemsMessage = _useFieldApi.noItemsMessage,
      validateOnMount = _useFieldApi.validateOnMount,
      meta = _useFieldApi.meta,
      helperText = _useFieldApi.helperText,
      isRequired = _useFieldApi.isRequired,
      FormGroupProps = _useFieldApi.FormGroupProps,
      maxItems = _useFieldApi.maxItems,
      minItems = _useFieldApi.minItems;

  var _useContext = useContext(BlueprintContext),
      required = _useContext.required;

  var _useStyles2 = useStyles(),
      addContainer = _useStyles2.addContainer;

  var error = meta.error,
      touched = meta.touched,
      submitError = meta.submitError;
  var showError = (validateOnMount || touched) && (error || submitError);
  var text = showError ? error : helperText || description;
  var intent = showError && error && {
    intent: Intent.DANGER
  };
  var labelInfo = isRequired && {
    labelInfo: required
  };

  var combinedLabels = _objectSpread({
    add: 'Add',
    remove: 'Remove'
  }, buttonLabels);

  return /*#__PURE__*/React.createElement(FormGroup, _extends({
    helperText: text,
    label: label
  }, labelInfo, FormGroupProps, intent), /*#__PURE__*/React.createElement(FieldArrayFF, {
    name: props.name,
    validate: arrayValidator
  }, function (fieldArrayProps) {
    return /*#__PURE__*/React.createElement("div", FieldArrayProps, fieldArrayProps.fields.length === 0 && noItemsMessage, fieldArrayProps.fields.map(function (name, index) {
      return /*#__PURE__*/React.createElement(ArrayItem, {
        key: index,
        remove: function remove() {
          return fieldArrayProps.fields.remove(index);
        },
        name: name,
        fields: fields,
        removeLabel: combinedLabels.remove,
        ArrayItemProps: ArrayItemProps,
        RemoveButtonProps: RemoveButtonProps,
        disabledRemove: fieldArrayProps.fields.length <= minItems
      });
    }), /*#__PURE__*/React.createElement("div", _extends({}, AddContainerProps, {
      className: clsx(addContainer, AddContainerProps && AddContainerProps.className)
    }), /*#__PURE__*/React.createElement(Button, _extends({
      onClick: function onClick() {
        return fieldArrayProps.fields.push(defaultItem);
      },
      intent: Intent.SUCCESS,
      disabled: fieldArrayProps.fields.length >= maxItems
    }, AddButtonProps), combinedLabels.add)));
  }));
};

FieldArray.propTypes = {
  name: PropTypes.string,
  defaultItem: PropTypes.any,
  fields: PropTypes.array,
  label: PropTypes.node,
  description: PropTypes.node,
  buttonLabels: PropTypes.object,
  AddContainerProps: PropTypes.object,
  AddButtonProps: PropTypes.object,
  RemoveButtonProps: PropTypes.object,
  ArrayItemProps: PropTypes.object,
  FormGroupProps: PropTypes.object,
  FieldArrayProps: PropTypes.object,
  noItemsMessage: PropTypes.node,
  validateOnMount: PropTypes.bool,
  helperText: PropTypes.node,
  isRequired: PropTypes.bool,
  maxItems: PropTypes.number,
  minItems: PropTypes.number
};
FieldArray.defaultProps = {
  noItemsMessage: 'No items'
};
export default FieldArray;
